"use strict";
// Copyright 2019 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
Object.defineProperty(exports, "__esModule", { value: true });
exports.pending = () => {
    // tslint:disable-next-line:no-any
    const active = {};
    let inc = 0;
    return {
        // so you can Promise.all() these active promises
        active: () => {
            return Object.values(active);
        },
        track: (p) => {
            if (inc + 1 === inc)
                inc = -1;
            active[inc++] = p;
            const _inc = inc;
            if (p.finally) {
                p.finally(() => {
                    delete active[_inc];
                });
                return p;
            }
            // tslint:disable-next-line:no-any
            let resolve, reject;
            const proxy = new Promise((res, rej) => {
                resolve = res;
                reject = rej;
            });
            p.then((value) => {
                delete active[_inc];
                resolve(value);
            }).catch((e) => {
                delete active[_inc];
                reject(e);
            });
            return proxy;
        }
    };
};
//# sourceMappingURL=pending.js.map